# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-10-25 18:00:46
@LastEditTime: 2022-12-13 15:06:40
@LastEditors: HuangJianYi
@Description: 
"""

from seven_framework import *
from seven_cloudapp_frame.models.db_models.counter.counter_config_model import *
from seven_cloudapp_frame.libs.customize.redis_helper import *


class CounterHelper:
    """
    :description: 计数帮助类 配置字段说明{"expire":计数过期时间，单位秒,"计数key":{"db_connect_key": 上下文,"table_name": 表名,"id_field_name": 主键字段名,"value_field_name": 返回字段名}}
    :sence:使用场景：1.珀莱雅H5评论列表走缓存，评论数和喜欢数又想保证计数实时 2.库存走reids并自动从数据库同步redis
    """
    logger_error = Logger.get_logger_by_name("log_error")

    @classmethod
    def amount(self, key_name, object_id, value, sync_update_db=True):
        """
        :description: 计数
        :param key_name: 计数key
        :param object_id: 对象标识
        :param value: 值
        :param sync_update_db: 是否同步更新数据库
        :return: 
        :last_editors: HuangJianYi 
        """
        try:
            object_id = str(object_id)
            counter_key = "counter:" + key_name
            counter_config_model = CounterConfigModel()
            counter_config_dict = counter_config_model.get_cache_dict("key_name=%s", params=[key_name])
            if not counter_config_dict:
                counter_config_dict = {}
            key_expire = int(counter_config_dict.get("key_expire", 0))
            if counter_config_dict.get("is_release", 0) == 0:
                counter_config_dict = {}
            db_connect_key = counter_config_dict.get("db_connect_key", "db_cloudapp")
            table_name = counter_config_dict.get("table_name", "")
            id_field_name = counter_config_dict.get("id_field_name", "")
            value_field_name = counter_config_dict.get("value_field_name", "")
            db_update_count = 0
            if sync_update_db == True and table_name and id_field_name and value_field_name:
                db = MySQLHelper(config.get_value(db_connect_key))
                sql = f'UPDATE {table_name} SET {value_field_name}={value_field_name}+{value} WHERE {id_field_name}=' + '%s'
                db_update_count = db.update(sql, [object_id])
            if sync_update_db == False or (sync_update_db == True and db_update_count > 0):
                init = RedisExHelper.init()
                count = init.hincrby(counter_key, object_id, value)
                if count == value:
                    db_value = self.get_db_amount(key_name, object_id)
                    init.hincrby(counter_key, object_id, db_value - value)
                if key_expire > 0:
                    init.expire(counter_key, key_expire * 3600)
                return count
            else:
                return 0
        except Exception as ex:
            self.logger_error.error("【计数】" + traceback.format_exc())
            return 0

    @classmethod
    def increment(self, key_name, object_id, value, sync_update_db=True):
        """
        :description: 增加计数
        :param key_name: 计数key
        :param object_id: 对象标识
        :param value: 增加的值
        :param sync_update_db: 是否同步更新数据库
        :return: 
        :last_editors: HuangJianYi 
        """
        return self.amount(key_name, object_id, abs(int(value)), sync_update_db)

    @classmethod
    def decrement(self, key_name, object_id, value, sync_update_db=True):
        """
        :description: 减少计数
        :param key_name: 计数key
        :param object_id: 对象标识
        :param value: 减少的值
        :param sync_update_db: 是否同步更新数据库
        :return: 
        :last_editors: HuangJianYi 
        """
        return self.amount(key_name, object_id, -int(value), sync_update_db)

    @classmethod
    def get_value(self, key_name, object_id):
        """
        :description: 获取计数值
        :param key_name: 计数key
        :param object_id: 对象标识
        :return: 
        :last_editors: HuangJianYi 
        """
        values = self.get_values(key_name, object_id)
        if len(values) > 0:
            return values[0]["value"]
        else:
            return 0

    @classmethod
    def get_values(self, key_name, object_ids):
        """
        :description: 获取计数值
        :param key_name: 计数key
        :param object_id: 对象标识数组
        :return: 
        :last_editors: HuangJianYi 
        """
        counter_key = "counter:" + key_name
        values = []
        init = RedisExHelper.init()
        if isinstance(object_ids, str):
            object_ids = object_ids.split(',')
        if isinstance(object_ids, int):
            object_ids = [str(object_ids)]
        try:
            counter_config_model = CounterConfigModel()
            counter_config_dict = counter_config_model.get_cache_dict("key_name=%s", params=[key_name])
            if not counter_config_dict:
                counter_config_dict = {}
            key_expire = int(counter_config_dict.get("key_expire", 0))
            for object_id in object_ids:
                cur_value = init.hget(counter_key, object_id)
                if cur_value:
                    values.append({"key": object_id, "value": int(cur_value)})
                else:
                    db_value = self.get_db_amount(key_name, object_id)
                    init.hincrby(counter_key, object_id, db_value)
                    if key_expire > 0:
                        init.expire(counter_key, key_expire * 3600)
                    values.append({"key": object_id, "value": db_value})
        except Exception as ex:
            self.logger_error.error("【获取计数值】" + traceback.format_exc())
        return values

    @classmethod
    def get_db_amount(self, key_name, object_id):
        """
        :description: 获取数据库计数值
        :param key_name: 计数key
        :param object_id: 对象标识
        :return: 
        :last_editors: HuangJianYi 
        """
        db_value = 0
        try:
            counter_config_model = CounterConfigModel()
            counter_config_dict = counter_config_model.get_cache_dict("key_name=%s", params=[key_name])
            if not counter_config_dict or counter_config_dict["is_release"] == 0:
                counter_config_dict = {}
            db_connect_key = counter_config_dict.get("db_connect_key", "db_cloudapp")
            table_name = counter_config_dict.get("table_name", "")
            id_field_name = counter_config_dict.get("id_field_name", "")
            value_field_name = counter_config_dict.get("value_field_name", "")
            if table_name and id_field_name and value_field_name:
                db = MySQLHelper(config.get_value(db_connect_key))
                db_value = db.query(f'SELECT {value_field_name} FROM {table_name} WHERE {id_field_name}=' + '%s LIMIT 1;', params=[object_id])
                if len(db_value) <= 0:
                    db_value = 0
                else:
                    db_value = int(db_value[0][value_field_name])
        except Exception as ex:
            self.logger_error.error("【获取数据库计数值】" + traceback.format_exc())
        return db_value



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-02 13:37:05
@LastEditTime: 2023-01-04 16:04:57
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.models.ip_base_model import *
from seven_cloudapp_frame.handlers.frame_base import *


class IpInfoListHandler(ClientBaseHandler):
    """
    :description: 获取ip列表
    """
    def get_async(self):
        """
        :description: 获取ip列表
        :param act_id：活动标识
        :param page_index：页索引
        :param page_size：页大小
        :param page_count_mode：分页模式(0-none 1-total 2-next)
        :return: list
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        page_index = self.get_param_int("page_index", 0)
        page_size = self.get_param_int("page_size", 10)
        page_count_mode = self.get_param_int("page_count_mode", 1)
        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
        page_list = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1", page_count_mode=page_count_mode)
        if page_count_mode == "total":
            total = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = PageInfo(page_index, page_size, total, page_list)
        elif page_count_mode == "next":
            is_next = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = WaterPageInfo(page_list, is_next)
        else:
            return_info = self.business_process_executed(page_list, ref_params={})
        return self.response_json_success(return_info)


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-27 10:57:24
@LastEditTime: 2022-01-21 16:34:17
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class TaoPayOrderModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(TaoPayOrderModel, self).__init__(TaoPayOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class TaoPayOrder:

    def __init__(self):
        super(TaoPayOrder, self).__init__()
        self.id = 0  # id(act_id+user_id+guid)md5int生成
        self.ascription_type = 0  # 归属类型（0-抽奖次数订单1-邮费次数订单2-任务订单）
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.goods_code = ""  # 商品编码
        self.goods_name = ""  # 商品名称
        self.sku_id = ""  # sku_id
        self.sku_name = ""  # sku_name
        self.buy_num = 0  # 购买数量
        self.pay_price = 0  # 购买金额
        self.main_pay_order_no = ""  # 淘宝主订单号
        self.sub_pay_order_no = ""  # 淘宝子订单号
        self.order_status = ""  # 订单状态
        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位)
        self.asset_object_name = ""  # 资产对象名称
        self.asset_object_id = ""  # 资产对象标识
        self.surplus_count = 0  # 剩余资产值
        self.prize_ids = ""  # 奖品ID列表（逗号隔开）
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.pay_date = "1900-01-01 00:00:00"  # 支付时间
        self.i1 = 0  # i1
        self.i2 = 0  # i2
        self.i3 = 0  # i3
        self.i4 = 0  # i4
        self.i5 = 0  # i5
        self.s1 = ""  # s1
        self.s2 = ""  # s2
        self.s3 = ""  # s3
        self.s4 = ""  # s4
        self.s5 = ""  # s5
        self.d1 = "1900-01-01 00:00:00"  # d1
        self.d2 = "1900-01-01 00:00:00"  # d2

    @classmethod
    def get_field_list(self):
        return ['id', 'ascription_type', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'goods_code', 'goods_name', 'sku_id', 'sku_name', 'buy_num', 'pay_price', 'main_pay_order_no', 'sub_pay_order_no', 'order_status', 'asset_type', 'asset_object_name', 'asset_object_id', 'surplus_count', 'prize_ids', 'create_date', 'pay_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "tao_pay_order_tb"
